@@ -12,6 +12,7 @@ from pynhost import dynamic
 class Command:
     def __init__(self, words, command_history):
         self.words = words
+        print(words)
         self.remaining_words = words
         self.command_history = command_history
         self.results = [] # result can be a string or a RuleMatch
@@ -22,16 +23,12 @@ class Command:
             if rule_match is not None:
                 self.results.append(rule_match)
                 self.remaining_words = rule_match.remaining_words
-                utilities.add_command_to_recording_macros(self, rule_match.rule.grammar.recording_macros)
-                # for name in rule_match.rule.grammar.recording_macros:
-                #     rule_match.rule.grammar.recording_macros[name].append(self)                                 
+                utilities.add_command_to_recording_macros(self, rule_match.rule.grammar.recording_macros)                              
             else:
                 self.results.append(self.remaining_words[0])
                 for grammars in gram_handler.modules.values():
                     for grammar in grammars:
                         utilities.add_command_to_recording_macros(self, grammar.recording_macros)
-                        # for name in grammar.recording_macros:
-                        #     grammar.recording_macros[name].append(self)
                 self.remaining_words = self.remaining_words[1:]
 
     def run(self):
@@ -75,7 +72,8 @@ class Command:
         elif isinstance(action, Command):
             action.run()
         elif isinstance(action, (types.FunctionType, types.MethodType)):
-            action(list(rule_match.matched_words.values()))
+            words = utilities.split_into_words(list(rule_match.matched_words.values()))
+            action(words)
         elif isinstance(action, int) and last_action is not None:
             for i in range(action):
                 self.handle_action(last_action, rule_match)
