@@ -9,7 +9,7 @@ class GrammarHandler:
     def __init__(self):
         self.modules = {}
 
-    def load_grammars(self):
+    def load_grammars(self, command_history):
         abs_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'grammars')
         for root, dirs, files in os.walk(abs_path):
             depth = len(root.split('/')) - len(abs_path.split('/')) 
@@ -20,7 +20,10 @@ class GrammarHandler:
                     path.append(filename[:-3])
                     rel = '.'.join(path) 
                     module = __import__('pynhost.{}'.format(rel), fromlist=[abs_path])
-                    self.modules[module] = self.extract_grammars_from_module(module)
+                    grammars = self.extract_grammars_from_module(module)
+                    for grammar in grammars:
+                        grammar.command_history = command_history
+                    self.modules[module] = grammars
    
     def extract_grammars_from_module(self, module):
         clsmembers = inspect.getmembers(sys.modules[module.__name__], inspect.isclass)
