@@ -14,12 +14,14 @@ class RuleMatch:
         self.snapshot = {'remaining words': None, 'matched words': None}
 
     def add(self, words, piece):
-        if isinstance(words, str):
-            self.remaining_words = self.remaining_words[1:]
-            self.matched_words[piece] = words
-            return
-        self.matched_words[piece] = ' '.join(words)
-        self.remaining_words = self.remaining_words[len(words):]
+        word_count = 1
+        if not isinstance(words, str):
+            word_count = len(words)
+            words = ' '.join(words)
+        if piece in self.matched_words:
+            words =  '{} {}'.format(self.matched_words[piece], words)
+        self.matched_words[piece] = words
+        self.remaining_words = self.remaining_words[word_count:]
 
     def take_snapshot(self):
         self.snapshot['remaining words'] = copy.deepcopy(self.remaining_words)
@@ -28,7 +30,9 @@ class RuleMatch:
     def revert_to_snapshot(self):
         self.remaining_words = self.snapshot['remaining words']
         self.matched_words = self.snapshot['matched words']
-        self.snapshot = {'remaining words': None, 'matched words': None}
+
+    def get_words(self):
+        return utilities.split_into_words(self.matched_words.values())
 
 def get_rule_match(rule, words):
     words = [word.lower() for word in words]
@@ -53,7 +57,10 @@ def get_rule_match(rule, words):
 def words_match_piece(piece, rule_match):
     if piece.mode == 'special':
         assert len(piece.children) == 1
-        return check_special(piece, rule_match)           
+        return check_special(piece, rule_match)
+    elif piece.mode == 'dict':
+        assert not piece.children
+        return check_dict(piece, rule_match)  
     buff = set()
     rule_match.take_snapshot()
     for child in piece.children:
@@ -62,7 +69,7 @@ def words_match_piece(piece, rule_match):
                 buff.add(False)
             else:
                 buff.add(True)
-                rule_match.add(child, child)
+                rule_match.add(child, piece)
         elif isinstance(child, ruleparser.RulePiece):
             buff.add(words_match_piece(child, rule_match))
         elif isinstance(child, ruleparser.OrToken):
@@ -77,6 +84,21 @@ def words_match_piece(piece, rule_match):
     if piece.mode != 'optional':
         return False
 
+def check_dict(piece, rule_match):
+    for k, v in rule_match.rule.dictionary.items():
+        key_split = k.split(' ')
+        for i, key_w in enumerate(key_split):
+            try:
+                if key_w.lower() != rule_match.remaining_words[i]:
+                    break
+            except IndexError:
+                break
+        else:
+            rule_match.matched_words[piece] = v
+            rule_match.remaining_words = rule_match.remaining_words[len(key_split):]
+            return True
+    return False 
+
 def check_special(piece, rule_match):
     tag = piece.children[0]
     if tag == 'num':
